@@ -58,11 +58,14 @@ class APIRequest(object):
              custom_asserter_list: List = None,
 
              is_default_json_extraction: bool = True,
+             is_default_json_asserter: bool = True,
              default_json_asserter_list: List[JSONAssertSchema] = None,
              default_custom_asserter_list: List = None,
              ):
         """
         http请求、执行器、断言、记录
+        :param is_default_json_extraction:
+        :param is_default_json_asserter:
         :param schema:
         :param data:
         :param query_params:
@@ -72,7 +75,6 @@ class APIRequest(object):
         :param custom_asserter_list:
         :param default_custom_asserter_list:
         :param default_json_asserter_list:
-        :param default_json_extraction:
         :return:
         """
         if not query_params:
@@ -87,10 +89,16 @@ class APIRequest(object):
         self.request.data = data
 
         if not is_default_json_extraction:
+            # 不执行默认json提取
             self.default_json_extraction = ''
-        if not default_json_asserter_list:
+        if default_json_asserter_list:
+            # 替换默认断言列表
             self.default_json_asserter_list = default_json_asserter_list
+        if not is_default_json_asserter:
+            # 不执行默认断言，情况列表
+            self.default_json_asserter_list = []
         if default_custom_asserter_list:
+            # 替换断言器列表
             self.default_custom_asserter_list = default_custom_asserter_list
 
         if schema:
@@ -114,6 +122,7 @@ class APIRequest(object):
         self.response = response
         if self.after:
             self.response = self.execution_processor(self.after, self.response)
+
         return APIResponse(self.response,
                            default_json_extraction=self.default_json_extraction,
                            default_json_asserter_list=self.default_json_asserter_list,
